@@ -97,7 +97,7 @@ class FunctionProbe(object):
             raise TypeError(
                 "Cannot probe: %s is not a function." % (repr(self.target),)
             )
-        varnames = base.func_code.co_varnames
+        varnames = self.maybe_unwrap(base).__code__.co_varnames
 
         @functools.wraps(base)
         def probe_wrapper(*args, **kwargs):
@@ -117,7 +117,7 @@ class FunctionProbe(object):
                             hotspots.enabled = True
 
             target_obj, target_func_name = self.target.rsplit(".", 1)
-            is_unwrapped = base.func_code.co_name == target_func_name
+            is_unwrapped = base.__code__.co_name == target_func_name
             if instruments_by_event["end"]:
                 # We have instruments that require evaluation in the local
                 # context of the function. Call sys.settrace() to gain access.
@@ -205,7 +205,8 @@ class FunctionProbe(object):
                     }
                     # Add positional args to locals by name.
                     for i, argname in enumerate(varnames[: len(args)]):
-                        _locals[argname] = args[i]
+                        if argname not in ("args", "kwargs"):
+                            _locals[argname] = args[i]
                     # Add kwargs to locals
                     _locals.update(kwargs)
 
@@ -232,7 +233,9 @@ class FunctionProbe(object):
                     if instruments_by_event["return"]:
                         end = time.time()
                         elapsed = end - start
-                        _locals.update({"result": result, "end": end, "elapsed": elapsed})
+                        _locals.update(
+                            {"result": result, "end": end, "elapsed": elapsed}
+                        )
 
                     for instrument in instruments_by_event["return"]:
                         try:
@@ -308,7 +311,21 @@ class FunctionProbe(object):
         if getattr(getattr(func, "__code__", None), "co_name", "") == "probe_wrapper":
             return func.__closure__[0].cell_contents
         else:
-            return func
+            try:
+                # If the given func is a func returned from @functools.wraps(orig),
+                # then the only cell in its closure will be the `orig` function.
+                # There may be funcs with a single cell that is a function
+                # that is not the wrapped function, in which case we will
+                # return the wrong signature here, but use of wraps is so
+                # much more common and SO useful to unwrap that we risk it.
+                if len(func.__closure__) == 1:
+                    f = func.__closure__[0].cell_contents
+                    if hasattr(f, "__code__"):
+                        return f
+            except (AttributeError, IndexError, TypeError):
+                pass
+
+        return func
 
     def make_getter(self, patch_id, parent):
         def callback(ref):
